AuthOwlLegalConfig class

Legal-consent policy for account creation.

Constructors

AuthOwlLegalConfig({required bool required, required int version, String? termsUrl, String? privacyUrl})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
privacyUrl String?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
termsUrl String?
final
version int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited